pub struct Datatracker { /* private fields */ }Implementations
Sourceimpl Datatracker
impl Datatracker
pub fn new() -> Self
Sourcepub fn email(&self, email: &str) -> Result<Email, DatatrackerError>
pub fn email(&self, email: &str) -> Result<Email, DatatrackerError>
Retrieve information about an email address.
This returns the information held about a particular email address.
If you want information about the person with a particular address,
use person_from_email().
pub fn email_history_for_address<'a>( &'a self, email: &'a str, ) -> Result<PaginatedList<'_, HistoricalEmail>, DatatrackerError>
pub fn email_history_for_person<'a>( &'a self, person: &'a Person, ) -> Result<PaginatedList<'_, HistoricalEmail>, DatatrackerError>
pub fn person(&self, person_uri: &PersonUri) -> Result<Person, DatatrackerError>
pub fn person_from_email(&self, email: &str) -> Result<Person, DatatrackerError>
pub fn person_aliases<'a>( &'a self, person: &'a Person, ) -> Result<PaginatedList<'_, PersonAlias>, DatatrackerError>
pub fn person_history<'a>( &'a self, person: &'a Person, ) -> Result<PaginatedList<'_, HistoricalPerson>, DatatrackerError>
pub fn people<'a>( &'a self, ) -> Result<PaginatedList<'a, Person>, DatatrackerError>
pub fn people_with_name<'a>( &'a self, name: &'a str, ) -> Result<PaginatedList<'a, Person>, DatatrackerError>
pub fn people_with_name_containing<'a>( &'a self, name_contains: &'a str, ) -> Result<PaginatedList<'a, Person>, DatatrackerError>
pub fn people_between<'a>( &'a self, start: DateTime<Utc>, before: DateTime<Utc>, ) -> Result<PaginatedList<'a, Person>, DatatrackerError>